@@ -4,8 +4,9 @@ import os
 # list available state machine
 
 
-def sfn_list(region):
-    client = boto3.client('stepfunctions', region_name=region)
+def sfn_list(region,AWS_ACCESS_KEY,AWS_SECRET_KEY):
+    client = boto3.client('stepfunctions', region_name=region,
+    aws_access_key_id=AWS_ACCESS_KEY,aws_secret_access_key=AWS_SECRET_KEY)
     response = client.list_state_machines()
     sfnList = []
     count = 0
